@@ -195,10 +195,11 @@ cloud_upload <- function(file, mimetype, itemid, chunk_size_bytes = pkg.env$chun
 		part_number <- part_number + 1
 		
 		refresh_token_before_expired()
+		session_renew()
 		
 		presignedUrl <- get_presigned_url_for_chunk(f_path, session_id, part_number, gql)
 		
-		put_chunk <- httr::PUT(presignedUrl, body = chunk)
+		put_chunk <- RETRY("PUT", presignedUrl, body = chunk)
 		
 		if(!put_chunk$status_code == 200) stop(paste("Error uploading file. \n",
 																					 "status:", put_chunk$status_code,
@@ -246,22 +247,30 @@ wait_till_up <- function(item, f) {
 	found <- FALSE
 	w <- 1
 	
+	wait_time <- 5
+	
 	while(!found) {
 		
-		files <- item_list_files(item)
+		refresh_token_before_expired()
+		session_renew()
 		
-		if(nrow(files > 1) && grepl(f, attr(files, "cloud")[[1]]$key)) {
+		files <- item_list_files(item, fetch_cloud_urls = FALSE)
+		
+		keys <- sapply(attr(files, "cloud"), function(x) x$key)
+		
+		if(nrow(files > 1) && any(grepl(f, keys))) {
 			found <- TRUE
 		} else {
-			Sys.sleep(5)
+			Sys.sleep(wait_time)
 		}
 		
 		w <- w + 1
 		
 		message("checking for uploaded file")
 		
-		if(w > 12) stop("cloud upload failed?")
-		
+		if(w > 20) stop("cloud upload failed?")
+	
+		wait_time <- wait_time * 2	
 	}
 	
 	return(as.sbitem(item))
